@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1335 USA
  */
 
 #ifndef GUCHARMAP_H
@@ -22,14 +22,17 @@
 
 #define __GUCHARMAP_GUCHARMAP_H_INSIDE__
 
-#define GUCHARMAP_VERSION_MAJOR (3)
-#define GUCHARMAP_VERSION_MINOR (2)
-#define GUCHARMAP_VERSION_MICRO (0)
+#include <glib.h>
 
-#define GUCHARMAP_CHECK_VERSION(major,minor,micro) \
-  (GUCHARMAP_VERSION_MAJOR > (major) || \
-   (GUCHARMAP_VERSION_MAJOR == (major) && GUCHARMAP_VERSION_MINOR > (minor)) || \
-   (GUCHARMAP_VERSION_MAJOR == (major) && GUCHARMAP_VERSION_MINOR == (minor) && GUCHARMAP_VERSION_MICRO >= (micro)))
+#if defined(GUCHARMAP_DISABLE_DEPRECATION_WARNINGS) || !GLIB_CHECK_VERSION (2, 31, 0)
+#define GUCHARMAP_DEPRECATED
+#define GUCHARMAP_DEPRECATED_FOR(f)
+#else
+#define GUCHARMAP_DEPRECATED G_DEPRECATED
+#define GUCHARMAP_DEPRECATED_FOR(f) G_DEPRECATED_FOR(f)
+#endif
+
+#include <gucharmap/gucharmap-version.h>
 
 #include <gucharmap/gucharmap-codepoint-list.h>
 #include <gucharmap/gucharmap-block-codepoint-list.h>
@@ -46,6 +49,8 @@
 
 #include <gucharmap/gucharmap-unicode-info.h>
 
+#undef GUCHARMAP_DEPRECATED
+#undef GUCHARMAP_DEPRECATED_FOR
 #undef __GUCHARMAP_GUCHARMAP_H_INSIDE__
 
 #endif /* #ifndef GUCHARMAP_H */
